factory

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 18, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Overview

Package factory constructs a provider.Provider from a config entry + OS keyring. Lives in its own package so concrete provider packages don't create an import cycle with the provider package that defines the Provider interface.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Build

func Build(_ context.Context, cfg *config.Config, name string) (provider.Provider, error)

Build returns a ready-to-use Provider for the named entry in cfg.Providers. It fetches the API key from the OS keyring and dispatches on pc.Type.

Types

This section is empty.

Jump to